# Security Policy

## Reporting a Vulnerability

**Do not open a public GitHub issue for security vulnerabilities.**

Instead, please report vulnerabilities through
[GitHub Security Advisories](https://github.com/alexsuw/easylora/security/advisories/new).

Include:

- A description of the vulnerability
- Steps to reproduce
- Potential impact
- Suggested fix (if any)

## Response Timeline

We aim to acknowledge reports within 72 hours and provide an initial assessment
within one week. Critical vulnerabilities will be prioritised for immediate
patching.

## Supported Versions

| Version | Supported |
|---------|-----------|
| 0.1.x   | Yes       |
